package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````0!X```````!``````````&"U````
M`````````$``.``(`$``'0`<``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````7`````````!<``````````0`````````!````
M!0```````````````````````````````````"2?````````))\`````````
M`"````````$````&````N*T```````"XK2```````+BM(```````J`0`````
M```0!0``````````(````````@````8```#@K0```````."M(```````X*T@
M``````#``0```````,`!````````"``````````$````!````!@"````````
M&`(````````8`@```````"P`````````+``````````$`````````%#E=&0$
M````?)@```````!\F````````'R8````````'`$````````<`0````````0`
M````````4N5T9`0```"XK0```````+BM(```````N*T@``````!(`@``````
M`$@"`````````0`````````O=7-R+VQI8F5X96,O;&0N96QF7W-O```'````
M!`````$```!.971"4T0``$`,JCL$````!`````,```!085@```````````!A
M````8P``````````````*0````H``````````````#`````+````.```````
M```H``````````$```!%````6@`````````:````1`````0````8````$```
M`!8````[````3P```%8`````````$P```#0```!1````6P````````!?````
M80```"<```!.````4````#P```!>````50```#X`````````00```#T````M
M````5````"`````D``````````4```!&``````````@````F````8@```%,`
M``!#````&P```$<```!@`````````%@`````````%````"(````Y````````
M````````````#@```"L``````````````%D````E``````````<`````````
M'@```#$`````````2`````,````_`````````#,`````````````````````
M````0@`````````R````2P```%P`````````70``````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````/````
M```````````````````````````````````````````=````'``````````C
M```````````````A```````````````)```````````````7````%0``````
M````````#0`````````L````*@```"\````9````````````````````````
M```````````````````````Z````'P```````````````````!(`````````
M-P````(````&````````````````````-@```$H```````````````````!-
M```````````````U``````````````!)`````````$`````,````````````
M``!,````$0```%(````N````5P``````````````````````````````````
M```````X`P``$@`````````````````````````,````$@``````````````
M```````````4````$@````````````````````````!@`P``$@`,`+`H````
M`````P`````````<````(@`````````````````````````K````$@``````
M```````````````````I`P``$@`````````````````````````Q````$@``
M``````````````````````!Q`P``$@`,`&TQ````````&@`````````X````
M$@`````````````````````````V`P``$@````````````````````````!`
M````$@````````````````````````",`P``$@`,``([````````90``````
M``"#````$@````````````````````````!(````$@``````````````````
M``````"8`P``$``7`&"R(`````````````````!8````$@``````````````
M``````````!G````$@````````````````````````!M````$@``````````
M``````````````!T````$@````````````````````````!^````$@``````
M``````````````````"(````$``-``!8``````````````````".````$@``
M```````````````````````Z`@``$@````````````````````````"7````
M$@````````````````````````">````$@````````````````````````"L
M````$@````````````````````````"]````$0``````````````````````
M``#*````$@````````````````````````"?`P``$@`,`)4J````````+P``
M``````"L`P``$@`,`,0J````````8`````````"X`P``$@`,`$4R````````
M@08```````#8````%@````````````````````````#K````$@``````````
M``````````````!(`P``$@````````````````````````#V````$@``````
M``````````````````#_````$0`8`,"R(```````"``````````'`0``$@``
M```````````````````````0`0``$@`````````````````````````<`0``
M$@````````````````````````#%`P``$@`,`')1````````YP$````````O
M`0``$0````````````````````````!!`0``$@``````````````````````
M``!1`0``$@````````````````````````!?`0``$@``````````````````
M``````!D`0``$@````````````````````````#0`P``$0`7`%BR(```````
M"`````````!S`0``$@````````````````````````!_`0``$@``````````
M``````````````"4`0``$@````````````````````````"?`0``$@``````
M``````````````````!;`P``$``8`,BR(`````````````````#J`@``$@``
M``````````````````````"R`0``$@`````````````````````````+!```
M$@`,`$`>``````````````````#``0``$@````````````````````````#(
M`0``(`````````````````````````#@`0``$@``````````````````````
M``#L`0``$@````````````````````````#:`P``$@`,`"0K````````#00`
M``````#R`0``(``````````````````````````(`@``$@``````````````
M```````````3`@``$@````````````````````````#G`P``$@`,`%E3````
M````D0(````````D`@``$@````````````````````````#Q`P``$``8`&"R
M(`````````````````#]`P``$@`,`#$H````````,@`````````%!```$@`,
M`/I5````````_`$````````K`@``$@`````````````````````````*!```
M$@`,`$`>```````````````````R`@``$@`````````````````````````2
M!```$@`,`+,H````````X@$````````?!```$@`,`(<Q````````O@``````
M```Y`@``$@`````````````````````````Q!```$@`,`#$O````````5@``
M``````!"`@``$@````````````````````````#3`@``$@``````````````
M``````````!3`@``(`````````````````````````!G`@``$@``````````
M```````````````_!```$@`,`(<O````````O`````````!V`@``$@``````
M``````````````````!_`@``$@````````````````````````"%`@``$@``
M```````````````````````<`P``$@````````````````````````"*`@``
M$@`````````````````````````/`P``$0`8`("R(```````"`````````"2
M`@``$@`````````````````````````]`P``$@``````````````````````
M``"9`@``$@````````````````````````!'!```$@`,`"%1````````40``
M``````"@`@``$@````````````````````````"O`@``$0``````````````
M```````````$`P``$0`7`/"Q(```````"`````````!*!```$``)`%`:````
M``````````````!0!```$@`,`,8X````````/`(````````H`0``$@``````
M``````````````````"T`@``$@````````````````````````!/`P``$@``
M````````````````````````;&EB<&5R;"YS;P!R96%L;&]C`&UE;6UO=F4`
M7U]C>&%?9FEN86QI>F4`<FUD:7(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?
M;'-T870U,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``;65M8W!Y`'!E<FQ?
M9&5S=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S
M=E]S971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I
M<@!E;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!?7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S<')I
M;G1F7V-H:P!R96%D`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?;F5W6%,`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<WES7W1E<FT`7U]E<G)N;P!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!097)L7VUG7W-E=`!M:V1I<@!?7W)E9VES=&5R7V9R86UE7VEN9F\`<&5R
M;%]P87)S90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`;65M8VAR
M`'9F<')I;G1F`%!E<FQ?871F;W)K7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E
M<P!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P<FEN=&8`
M9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M<`!L:6)M
M+G-O+C``;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS;RXQ`'!T
M:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN
M9W,`7U]G971P=W5I9#4P`%]?<W1P8W!Y7V-H:P!A=&5X:70`7VQI8F-?:6YI
M=`!S=')T;VL`7U]R96%D9&ER,S``7V5N9`!P87)?8W5R<F5N=%]E>&5C`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!P
M87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A
M=&4`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A
M<G0`>'-?:6YI=`!M86EN`%]?<W1A<G0`<&%R7V9I;F1P<F]G`'!A<E]S971U
M<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R7V1I90!S:&%?:6YI=`!84U])
M;G1E<FYA;'-?4$%27T)/3U0`+W5S<B]P:V<O;&EB+W!E<FPU+S4N-#(N,"]X
M.#9?-C0M;F5T8G-D+71H<F5A9"UM=6QT:2]#3U)%.B]U<W(O<&MG+VQI8@``
M``#@KR````````@`````````X*T@``````#PL2````````@`````````B+(@
M``````#XL2````````@`````````^+$@``````!8LB````````@`````````
M^%H```````"@KR````````8````%``````````````"HKR````````8````/
M``````````````"PKR````````8````<``````````````"XKR```````!(`
M```A``````````````#`KR````````8````J``````````````#(KR``````
M``8````S``````````````#0KR````````8````Y``````````````#8KR``
M``````8````]``````````````#HKR````````8```!,``````````````#P
MKR````````8```!.``````````````#XKR````````8```!<````````````
M```8L"````````<````!```````````````@L"````````<````"````````
M```````HL"````````<````#```````````````PL"````````<````&````
M```````````XL"````````<````'``````````````!`L"````````<````(
M``````````````!(L"````````<````*``````````````!0L"````````<`
M```+``````````````!8L"````````<````,``````````````!@L"``````
M``<````.``````````````!HL"````````<````1``````````````!PL"``
M``````<````2``````````````!XL"````````<````3``````````````"`
ML"````````<````4``````````````"(L"````````<````5````````````
M``"0L"````````<````7``````````````"8L"````````<````8````````
M``````"@L"````````<````9``````````````"HL"````````<````:````
M``````````"PL"````````<````;``````````````"XL"````````<````=
M``````````````#`L"````````<````B``````````````#(L"````````<`
M```C``````````````#0L"````````<````D``````````````#8L"``````
M``<````F``````````````#@L"````````<````G``````````````#HL"``
M``````<````H``````````````#PL"````````<````K``````````````#X
ML"````````<````L````````````````L2````````<````M````````````
M```(L2````````<````N```````````````0L2````````<````P````````
M```````8L2````````<````Q```````````````@L2````````<````R````
M```````````HL2````````<````U```````````````PL2````````<````V
M```````````````XL2````````<````X``````````````!`L2````````<`
M```Z``````````````!(L2````````<````[``````````````!0L2``````
M``<````^``````````````!8L2````````<````_``````````````!@L2``
M``````<```!!``````````````!HL2````````<```!%``````````````!P
ML2````````<```!'``````````````!XL2````````<```!*````````````
M``"`L2````````<```!-``````````````"(L2````````<```!/````````
M``````"0L2````````<```!1``````````````"8L2````````<```!2````
M``````````"@L2````````<```!3``````````````"HL2````````<```!4
M``````````````"PL2````````<```!5``````````````"XL2````````<`
M``!7``````````````#`L2````````<```!8``````````````#(L2``````
M``<```!9``````````````#0L2````````<```!;``````````````#8L2``
M``````<```!@``````````````#@L2````````<```!A``````````````#H
ML2````````<```!B`````````````````````````$B#[`CH0@<``$B#Q`C#
M``#_-:*5(`#_):25(``/'T``_R6BE2``:`````#IX/____\EFI4@`&@!````
MZ=#_____)9*5(`!H`@```.G`_____R6*E2``:`,```#IL/____\E@I4@`&@$
M````Z:#_____)7J5(`!H!0```.F0_____R5RE2``:`8```#I@/____\E:I4@
M`&@'````Z7#_____)6*5(`!H"````.E@_____R5:E2``:`D```#I4/____\E
M4I4@`&@*````Z4#_____)4J5(`!H"P```.DP_____R5"E2``:`P```#I(/__
M__\E.I4@`&@-````Z1#_____)3*5(`!H#@```.D`_____R4JE2``:`\```#I
M\/[___\E(I4@`&@0````Z>#^____)1J5(`!H$0```.G0_O___R42E2``:!(`
M``#IP/[___\E"I4@`&@3````Z;#^____)0*5(`!H%````.F@_O___R7ZE"``
M:!4```#ID/[___\E\I0@`&@6````Z8#^____)>J4(`!H%P```.EP_O___R7B
ME"``:!@```#I8/[___\EVI0@`&@9````Z5#^____)=*4(`!H&@```.E`_O__
M_R7*E"``:!L```#I,/[___\EPI0@`&@<````Z2#^____);J4(`!H'0```.D0
M_O___R6RE"``:!X```#I`/[___\EJI0@`&@?````Z?#]____):*4(`!H(```
M`.G@_?___R6:E"``:"$```#IT/W___\EDI0@`&@B````Z<#]____)8J4(`!H
M(P```.FP_?___R6"E"``:"0```#IH/W___\E>I0@`&@E````Z9#]____)7*4
M(`!H)@```.F`_?___R5JE"``:"<```#I</W___\E8I0@`&@H````Z6#]____
M)5J4(`!H*0```.E0_?___R52E"``:"H```#I0/W___\E2I0@`&@K````Z3#]
M____)4*4(`!H+````.D@_?___R4ZE"``:"T```#I$/W___\E,I0@`&@N````
MZ0#]____)2J4(`!H+P```.GP_/___R4BE"``:#````#IX/S___\E&I0@`&@Q
M````Z=#\____)1*4(`!H,@```.G`_/___R4*E"``:#,```#IL/S___\E`I0@
M`&@T````Z:#\____)?J3(`!H-0```.F0_/___R7RDR``:#8```#I@/S___\E
MZI,@`&@W````Z7#\____)>*3(`!H.````.E@_/___R7:DR``:#D```#I4/S_
M__\ETI,@`&@Z````Z4#\____)7J1(`!FD/\EHI$@`&:0_R6BD2``9I#_);*1
M(`!FD$B#Y/!(@^P(2(G72(G>Z<X!``!F+@\?A```````#Q\`54B)Y4%44TB-
M'4J/(`!,C25#CR``3#GC<PO_$TB#PPA,.>-R]5M!7%W#54B)Y4%505132(/L
M"$C'PP````!)Q\4`````3#GK<QV#>P@E#X4\-P``3(LC_U,028D$)$B#PQA,
M.>MRXTB#Q`A;05Q!75W#2&/22&/V2(U$,@)(C13'BP*%P`^$,@$``+[_____
M,<GK$X/X`P^$%P$``$B#PA"+`H7`=""#^`5T#8/X!W7C2(-Z"`!TY<,/MW((
M2(/"$(L"A<!UX$B%R0^$[0```&:#_O\/A.,````/M\9(:\`X2`'(2#G(#X;0
M````OO____\Q_^L5@_H&=0=(B<Y(*W$02(/!.$@YR'83BQ&#^@)UY$B)STB#
MP3A(.<AW[4B%_P^$E@```+C_____2#G&#X2(````2(M/$$@!\4B+$4B%TG1Y
M,?\QP.L62(/Z"'4$2(MY"$B#P1!(BQ%(A=)T&4B#^@=UY$B+00A(`?!(@\$0
M2(L12(72=>=(`<=(.<=W%>LZ2(M0$$@!\DB)$4B#P!A(.<=V)TB+"$@!\8M0
M"$B#^@ATWDB#^B5TXE5(B>7IX34``$B+2@CIX/[__P\?`,-52(GE059!54%4
M4TF)_DF)](M6&(MV"$F+/"3HD?[__TB-!3B2(`!,B2!,C2UNDB``28M$)!!)
MB44`28L$)$B+$$B%T@^$N0```$B-#7Z1(`!(B1%(BP`/MA"$TG032(/``8#Z
M+W7P2(D!#[80A-)U[4V%]G0(3(GWZ$'Z___H'/W__TB#/32/(```#X2(````
M3(TU_XP@`$B-'?B,(`!,.?-S"_\32(/#"$PY\W+U2(T]B?W__^@$^O__3(TU
MU8P@`$B-'<Z,(`!,.?-S"_\32(/#"$PY\W+U2(T]_S8``.C:^?__Z$7Y__]!
MBWPD"$F+50!)BS0DZ-TT``")Q^A,^?__2(T%Q9`@`$B-#5:1(`!(B0CI6/__
M_^A+_?__Z6[___^`/?:0(```=`'#4\8%ZY`@``%(@SU"CB```'0,2(L]D9`@
M`.BT_/__2(T=78P@`$B+`TB%P'0(_]!(@\,(Z_!(@SU%CB```'0,2(T]5'D`
M`.B/_/__6\.`/9Z0(```=`'#4\8%DY`@``%(@STCCB```'032(TU0I`@`$B-
M/2-Y``#H9OS__TB#/1Z.(```=!)(C3W]BR``2(,_`'0%Z%+\__](C1W+BR``
M2(L#2(/X_W0(_]!(@^L(Z^];PU5(B>5!5T%6055!5%-(@^P82(EUR$B%_P^$
MAP```$B-!9N0(`!,BS!-A?9T>$F)_P^V!TB)^H3`='`\/70+2(/"`0^V`H3`
M=?%$*?I-BR9-A>1T*TQCZDR)\TR)ZDR)_DR)Y^AH^/__A<!U!T.`/"P]=!Y(
M@\,(3(LC387D==M,B>!(@\086T%<05U!7D%?7<-,*?-(P?L#2(M%R(D83XUD
M+`'KVD4QY.O5,=+KGE5(B>5!5T%6055!5%-(@>RX````2(L=]XP@`$B+`TB)
M1<@QP$B%_W0(28G\@#\`=1](BT7(2"L##X46`0``2('$N````%M!7$%=05Y!
M7UW#Z/WX__])B<9(A<!TU$B-A3#___](B84H____3(GWZ._Z__](A<`/A)P`
M``!,C7@-@'@-+G4'08!_`0!TWH!X#2X/A)8```!,B>?H@_K__TF)Q4R)_^AX
M^O__08U\!0)(8__HB_K__TF)Q4R)^4R)XDB--9LT``!(B<<QP.@A^O__2(NU
M*/___TR)[^C2]___3(GO@_C_=!*+A3C___\E`/```#T`0```=$[H@_?__TR)
M[^A+]___3(GWZ%/Z__](A<`/A63___],B??H$OC__TR)Y^C*]O__Z03___]!
M@'\!+@^%7____T&`?P(`#X0H____Z4_____HL_[__P\?1```ZZOHF??__U5(
MB>5!5%-(@>R@````28G\2(L=H8L@`$B+`TB)1>@QP$B-M5#____H#/?__X7`
M=3.+E5C___^!X@#P``"!^@!```!T"('Z`*```'49O@(```!,B>?HG_C__X7`
M#Y3`#[;`ZP(QP$B+3>A(*PMU#$B!Q*````!;05Q=P^@9]___54B)Y4%44TB!
M[!`$``!(B?Y(BQTABR``2(L#2(E%Z#'`3(VEX/O__[H`!```3(GGZ/3U__](
M@^@!3#G@=P[K$<8``$B#Z`%,.>!T!8`X+W3OOB\```!,B>?H"_;__TB%P'0G
M3#G@=QU,B>?H2?C__TB+3>A(*PMU,4B!Q!`$``!;05Q=P\8``.O>2(M%Z$@K
M`W472(T]]3(``$B!Q!`$``!;05Q=Z0_X___H:O;__U5(B>5!5T%6055!5%-(
M@>P8!```28G\28GU2(L=:8H@`$B+`TB)1<@QP$R-M<#[__^Z_P,``$R)]DB-
M/:(R``#H=?;__X7`?DV-4/],8_I"@+P]P/O__P!U=872=#A,B?J^+P```$R)
M]^A\]___2(7`="-D2(L$)0````!(`P7_B2``3(GY3(GR3(GF2(LXZ(;W___K
M'F1(BP0E`````$@#!=R)(`!,B>I,B>9(BSCHQO7__TB+1<A(*P-U%TB!Q!@$
M``!;05Q!74%>05]=PTQC^.N*Z)'U__]52(GE05=!5D%505132(/L*$F)_$F)
M]DB+!9.)(`!(BQA(B5W(,=N`/CUU!$F#Q@%,B??HB??__TF)Q4B-=<1,B><Q
MP.BH^___28G'2(7`#X3I````2(G'Z&3W__]).<4/AKX```!(8TW$2(T<S0``
M``!,C3TXC"``00^V%"1,B>"$TG40Z7\!``!(@\`!#[80A-)T!8#Z/77P3"G@
M2)A)`Q]*C7PH`N@U]___2(D#2(7`=$U(8U7$28L'2(LTT$F-3"0!00^V!"2(
M!H3`=1'K:$B#P0$/MD'_B$(!A,!T64B)\DB-=@$\/77FQ@(],<!!#[8,!HA,
M`@%(@\`!A,EU[TB+!:F((`!(BUW(2"L8#X4(`0``2(/$*%M!7$%=05Y!7UW#
M,<!!#[84!D&(%`=(@\`!A-)U[^O(2(GRZZU,C3ULBR``38L/28,Y``^$O@``
M`$R)R$4QP$B#P`A$B<)!@\`!2(,X`'7OC4(#2)A(P>`#BQ4)BR``A=)$B46\
M=5Y,B4VPQP7SBB```0```$B)Q^A+]O__2(G'2(7`#X1?____2&--O$B-',T`
M````2(G:3(M-L$R)SNC$\O__2(G'28D'1(M%O$&-0`%(F$C'!,<`````1(E%
MQ.F;_O__2(G&3(G/Z(CR__](B<=)B0=(A<`/A`G___](8TV\28G(2(T<S0``
M``#KOC'`Z8_^__^X$````$4QP.E5____Z&_S__]52(GE9$B+!"4`````2`,%
M<X<@`$B-#21P``!(BQ55AR``2(TUT"\``$B+.%WI'?3__U5(B>532(/L"&1(
MBP0E`````$@#!3R'(`!(B<-(BSCHJO___T4QR4R-!34Q``!,B<%(C14K$```
M2(TUI"\``$B+.TB#Q`A;7>E`]/__,<##54B)Y4%7059!54%44TB![-@$``!)
MB?Q)B?9,BRWLAB``28M%`$B)1<@QP$B-M1S[__](C3UO+P``Z`_Y__](B<.^
M+P```$R)Y^B_\?__2(7`=#1,B>9(C3U4+P``,<#H^/S__TR)X$B+5<A)*U4`
M#X5F`0``2('$V`0``%M!7$%=05Y!7UW#3(GWZ/[S__](B<=(C34E+P``Z'_R
M__])B<=(A<!TK4&`/P`/A-H```!(A=MT$TR)_DB)W^B-]/__A<`/A)X```!,
MB?_H3?3__TF)QDF-1`?_23G'<@[K',8``$B#Z`%).<=T!8`X+W3O3(G_Z"7T
M__])B<9,B>?H&O3__TF-1`8!2#W_`P``#X<_____3(VUP/O__TR))"1,C0U_
M+P``38GX2(T-F"\``+H`!```,?9,B?<QP.@\\O__2(VU(/O__TR)]^A=\?__
MA<!U$HN%*/O__R4`\```/0"```!T2$B--5$N```Q_^BI\?__28G'2(7`#X33
M_O__08`_``^%)O___TB%VW0%@#LN=!)!O@$```!,C3W"+0``Z57___^`>P$`
M=+KKYKX!````3(GWZ)+R__^%P'6G3(GV2(T]Z"T``.B.^___3(GWZ+?R___I
MC/[__V:0Z`OQ__]52(GE051(@^P(28G\OB\```#H1/#__TB%P'0$3(U@`4R)
MYTB#Q`A!7%WI?/+__TB%_W1/54B)Y4%42(/L"$F)_(`_`'0@Z/#R__](@\`!
M2#T`!```=R),B>=(@\0(05Q=Z8SY__](C3T4+0``2(/$"$%<7>DR\O__,<!(
M@\0(05Q=PTB-/?<L``#I'/+__U5(B>5!54%44TB#[!A(BQV(A"``2(L#2(E%
MV#'`3(UEU$R-+2<M``!,B>9,B>\QP.BG]O__2(7`=#!(8U742(T%5X<@`$B+
M`$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)$$B%TG7PZ[Y,C2WG+```3(GF
M3(GO,<#H7O;__TB%P'0P2&-5U$B-!0Z'(`!(BP!(C0302(M0"$B)$$B%TG30
M2(/`"$B+4`A(B1!(A=)U\.N^3(TMIBP``$R)YDR)[S'`Z!7V__](A<!T,$AC
M5=1(C07%AB``2(L`2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D02(72=?#K
MODR-+68L``!,B>9,B>\QP.C,]?__2(7`=#!(8U742(T%?(8@`$B+`$B-!-!(
MBU`(2(D02(72=-!(@\`(2(M0"$B)$$B%TG7PZ[Y,C2TD+```3(GF3(GO,<#H
M@_7__TB%P'0P2&-5U$B-!3.&(`!(BP!(C0302(M0"$B)$$B%TG302(/`"$B+
M4`A(B1!(A=)U\.N^3(TMZRL``$R)YDR)[S'`Z#KU__](A<!T,$AC5=1(C07J
MA2``2(L`2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D02(72=?#KODR-+5DK
M``!,B>9,B>\QP.CQ]/__2(7`=#!(8U742(T%H84@`$B+`$B-!-!(BU`(2(D0
M2(72=-!(@\`(2(M0"$B)$$B%TG7PZ[Y,C2UE*P``3(GF3(GO,<#HJ/3__TB%
MP'0P2&-5U$B-!5B%(`!(BP!(C0302(M0"$B)$$B%TG302(/`"$B+4`A(B1!(
MA=)U\.N^3(TM)BL``$R)YDR)[S'`Z%_T__](A<!T,$AC5=1(C04/A2``2(L`
M2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D02(72=?#KODR-+><J``!,B>9,
MB>\QP.@6]/__2(7`=#!(8U742(T%QH0@`$B+`$B-!-!(BU`(2(D02(72=-!(
M@\`(2(M0"$B)$$B%TG7PZ[Y,C2T^*@``3(GF3(GO,<#HS?/__TB%P'0P2&-5
MU$B-!7V$(`!(BP!(C0302(M0"$B)$$B%TG302(/`"$B+4`A(B1!(A=)U\.N^
M3(GF2(T]7"H``.B)\___2(G&2(7`=`Y(C3TT*@``,<#H@O?__TR)YDB-/4@J
M```QP.AB\___2(G&2(7`=`Y(C3U$*@``,<#H6_?__TR)YDB-/3XJ```QP.@[
M\___2(G&2(7`=#9(C3V'*0``,<#H-/?__TB+1=A(*P-U2$B--3(J``!(C3VB
M*0``,<!(@\086T%<05U=Z0SW__],B>9(C3W_*0``,<#H[/+__TB)QDB%P'2_
M2(T]C2D``#'`Z.7V___KK^AO[/__54B)Y5-(@^P82(L=?X`@`$B+`TB)1>@Q
MP$B-=>1(C3U;*0``Z*;R__](A<!T'P^V`(3`=!@\,`^5P`^VP$B+5>A(*Q-U
M"TB#Q!A;7<,QP.OLZ!GL__]52(GE2('LT````$F)^DB)M5C___](B95@____
M2(F-:/___TR)A7#___],B8UX____A,!T(`\I18`/*4V0#RE5H`\I7;`/*67`
M#REMT`\I=>`/*7WP2(L%W7\@`$B+"$B)C4C___\QR<>%,/___P@```#'A33_
M__\P````2(U%$$B)A3C___](C850____2(F%0/___TB-E3#___],B=9(BP7+
M?R``2(VX,`$``.CW[/__O_\```#H+>K__U5(B>5!5T%6055!5%-(@>P8``$`
M08G]3(LE7W\@`$F+!"1(B47(,<"Z`@```#'VZ/GL__](@^@!2+K__P``````
M@$@APGD/2(/J`4B!R@``__](@\(!3(V]P/_^_TR--7@H``!(*=!(B<,/B)T`
M```QTDB)WD2)[^BP[/__2(/X_P^$CP```+H(``$`3(G^1(GOZ&;K__](8]"#
M^/]T3$B#^@=V5$F-1!?X3#GX<DI(C15/@2``ZPE(@^@!3#GX<CA(BPA(.0IU
M[TPI^$@!V$B+=<A)*S0D=4Q(@<08``$`6T%<05U!7D%?7<-(C3WW)P``,<#H
M2_[__TB!ZP```0!(@?L``/__#X5C____2,?`_____^NY3(GW,<#H)/[__^EB
M____Z#/J__]52(GEZ#KL__^)Q^@3[/__2(7`=`-(BP!=PU5(B>5!5D%50513
M2(/L$$F)_$R++2!^(`!)BT4`2(E%V#'`2(UUU$B-/8,G``#H1O#__TB%P'0(
M2(G#@#@`=2=(BT7822M%`'5J3(GF2(T]72<``#'`2(/$$%M!7$%=05Y=Z2'T
M__],B>?HVNO__TF)QDB)W^C/Z___28U\!@+HY>O__TF)QDF)V$B-#5DF``!,
MB>)(C359)P``2(G',<#H=.O__TB+1=A)*T4`=05,B?;KF0\?1```Z%OI__]5
M2(GE05=!5D%505132('LB`$``$B)O6C^__](BP59?2``2(L(2(E-R#')2(T%
MW28``$B)A8#^__](C061)0``2(F%B/[__TC'A9#^__\`````2(T%3"8``$B)
MA<C^__](C06N)@``2(F%T/[__TB-!4TF``!(B878_O__2(T%FB8``$B)A>#^
M__](QX7H_O__`````$B-!84F``!(B86H_O__2,>%L/[__P````!,C:U\_O__
M3(GN2(T]5R4``#'`Z/7N__](A<!T"8`X``^%2@0``#'`Z$W^__])B<9(A<`/
MA,,#``!,B??HG.K__TB-?``!Z++J__](B<-!#[86A-)T*DF)WTR-)1PF```/
MMM),B>9,B?\QP.@]ZO__28/&`4F#QP)!#[86A-)UX$R-M<#^__](C3UP)0``
MZQ!)@\8(28L^2(7_#X04`0``3(GN,<#H8^[__TF)Q$B%P'3>@#@`=-E(B<?H
M5?#__X7`=,U,B>?H@NG__TB)PDB%P`^$W0```$B)UTB)E6#^___H]^G__TF)
MQ$B)W^CLZ?__18VD!`0$``!-8^1,B>?H^>G__TF)QDF)V4R-!7`E``!(C0U-
M)0``2(N58/[__TB--6`E``!(B<<QP.A]Z?__OL`!``!,B??HH.C__X/X_P^$
M;P(``$B-M?#^__],B??H^.;__XG#A<`/A+(```!,B?%(BX5H_O__2(L02(TU
MRB4``$B+!8M[(`!(C;@P`0``,<#H]>;__T4QY$B+!3M[(`!(BTW(2"L(#X4O
M!```3(G@2('$B`$``%M!7$%=05Y!7UW#3(NU@/[__T4QY.L026/$3(NTQ8#^
M__]-A?9T.D&`/@!T-$R)]^@V[___08/$`87`=-I,B??H7^C__TB)PDB%P`^%
MW?[__TECQ$R+M,6`_O__387V=<8QTNG&_O__BX7X_O__)0#P```]`$````^%
M./___XN%#/___T&)Q^B(Z/__03G'#X4A____BX7X_O__)?\!```]P`$```^%
M"____TR)Y^BAZ/__28G$3(GN2(T]YR,``#'`Z)WL__](B<9(A<`/A#<"``!(
MBX5H_O__2(LXZ#7S__])B<5(A<`/A!P"``!,B>_H/NC__X/X`WXZ2&/028UT
M%?RY!0```$B-/=<C``#SI@^7PH#:`(32=1J#^`0/A+@"``"#Z`5(F$&`?`4`
M+P^$IP(``#'`Z%GY__^%P'45,?9,B>_HFN?__T&)Q87`#X7$`0``2(TU)2,`
M`$B-/;$B```QP.@)\/__Z`7G__]!B<!,C0VQ(P``2(T-/",``$R)\DB--8`C
M``!,B><QP.APY___3(TMCR,``.LWZ'+F__^#.!%U/X/#`>C%YO__08G`3(DL
M)$&)V4B-#?PB``!,B?)(C35.(P``3(GG,<#H,.?__[[``0``3(GGZ%/F__^#
M^/]TMTR)]^AVY/__3(GF2(T]QR$``#'`Z'3O__],B>?HY/K__^G6_?__Z`/F
M__^#.!$/A(/]___H]>7__T2+`$R)\4B+A6C^__](BQ!(C34>(P``2(L%'WD@
M`$B-N#`!```QP.B)Y/__13'DZ8_]__\QVTB-/5`B``#K$$ACPTB+O,6@_O__
M2(7_=#M,B>XQP.CLZO__@\,!2(7`=-Z`.`!TV4B)Q^@7YO__28G&2(7`#X7W
M^___2&/#2(N\Q:#^__](A?]UQ;\-````Z*'F__](B<-,C37T(0``NE,```#I
MYOO__TB)QTB)A6C^___H%?K__TB+!4=X(`!(BTW(2"L(2(N%:/[__P^%-`$`
M`$B)QTB!Q(@!``!;05Q!74%>05]=Z9KE__](BX5H_O__3(LHZ=7]__^)Q^B'
M^/__28G'2(7`#X@I_O__2(UP]C'21(GOZ)KE__](C76*N@8```!$B>_H6>3_
M_TB#^`9T#DB-/9@A```QP.B,]___@7V*`$-!0P^%Z?W__V:!?8Y(10^%W?W_
M_TF-=\XQTD2)[^A.Y?__2(U=D+HH````2(G>1(GOZ`KD__](@_@H=`Y(C3U)
M(0``,<#H/??__\9%N`!,C0UQ(0``28G82(T-^2```$R)\DB--2XA``!,B><Q
MP.@MY?__Z0K^__](BX5H_O__3(MX"$V%_P^$1?W__TR)_^@\Y?__2(/X`P^&
M,_W__TF-=`?\N04```!(C3W8(```\Z8/E\`<`(3`30]$[^D0_?__Z-KB__]5
M2(GE059!54%44TB#[!!,BR7D=B``28L$)$B)1=@QP&1(BP0E`````$@#!<)V
M(`!(BP`/MI"P````B)"Q````3(UMU$R)[DB-/8`?```QP.CEZ/__2(7`=`F`
M.#$/A(`!```QP.CT\?__9$B+!"4`````2`,%>'8@`$F)QKD#````N@$```!(
MC35Q(```2(LXZ,3B__](B<-(A<!T)TB+0!!(C158(```2(LP28L^Z#;B__](
MBT,02(LP]D8.0`^%1`$``&1(BP0E`````$@#!1UV(`!)B<:Y`P```+H!````
M2(TU'2```$B+..AIXO__2(G#2(7`="Q,B>Y(C3V;'@``,<#H,.C__TB)PDB+
M0Q!(A=(/A-@```!(BS!)BS[HQ>'__V1(BP0E`````$@#!;UU(`!(B<.Z`0``
M`$B--<0?``!(BSCH3N+__TB)QDB-%<<?``!(BSOHC.'__TB+`\:`L0````!,
MB>Y(C3TC'@``,<#HP>?__TB)QTB)!4]X(`!(A<!T,K[``0``Z'CB__^#^!%T
M"(U0`8/Z`7=W2(M%V$DK!"0/A8H```!(@\006T%<05U!7EW#2(L]&7@@`.BY
M]___2(G'2(D%`G@@`$B%P'6S2(T]YA\``#'`Z,?A__^`>`$`#X1]_O__Z7'^
M__](BQ7A=R``2(LR2(LXZ&SJ___I'/___TF+/NCIX?__Z:_^__^)P4B+%;-W
M(`!(BP6T=R``2(LP2(T]NA\``#'`Z'/A___HGN#__U5(B>5!5$B#[`A)B?PQ
MP.@;]/__A<!T#$V%Y'0'08`\)`!U"$B#Q`A!7%W#3(GGZ([O__](B<?H5^__
M_[D$````2(T]*AX``$B)QO.F#Y?`'`"$P'7.3(GG2(/$"$%<7>E'Y___9@\?
MA```````54B)Y4%7059!54%44TB![)@"``!(BP4U="``2(L82(E=R#';3(U'
M.$B-E4#]__],C8W`_?__2(G608L`#\A-BQ!)@\`(B<!(B09,B=%(P>D@3(G0
M2,'H*"4`_P``2<'J.$P)T$F)RDG!XAA%B=),"=!(P>$(@>$``/\`2`G(2(E&
M"$B#QA!,.<YUKDB-L@`"``!(BT)H2#-"0$@S0A!(,P)(C0P`2,'H'T@)R(/@
M_TB)@H````!(@\((2#GR==-,BP],BU\02(M?&$R)R$C!X`5,B<I(P>H;2`G0
M`X5`_?__2(MW((V4,)EY@EI,B=A(,=A((T<(2#'8C30"2(M7"$C!XAY(BT<(
M2,'H`D@)T$&)P$R)VDPQPDPARDPQVDB+C4C]__](C8P+F7F"6D@!RDB)\4C!
MX05)B?))P>H;3`G11(TL"DR)R4C!X1Y,B<I(P>H"2`G*B=%(,=!((?!,,<!,
MBY50_?__3XV4$YEY@EI,`=!-B>I)P>(%38GL2<'L&TT)XD:-)!!(B?!(P>`>
M2,'N`D@)\(G&2#'"3"'J2#'*3(N56/W__T^-A!"9>8):20'03(GB2,'B!4V)
MXDG!ZAM,"=)%C10038GH2<'@'DG![0)-">A$B<),,<!,(>!(,?!,BZU@_?__
M2HV,*9EY@EI(`<%,B=!(P>`%38G52<'M&TP)Z$2-+`%,B>%(P>$>2<'L`DP)
MX8G(23'(32'023'03(NE:/W__TJ-M":9>8):20'P3(GN2,'F!4V)[$G![!M,
M">9%C20P3(G62,'F'DG!Z@),"=9!B?!(,?%,(>E(,<%,BY5P_?__2HV4$IEY
M@EI(`=%,B>)(P>(%38GB2<'J&TP)TD2-%!%,B>I(P>(>2<'M`DP)ZHG12#'6
M3"'F3#'&3(NM>/W__TJ-A"B9>8):2`'&3(G02,'@!4V)U4G![1M,">A$C2P&
M3(G@2,'@'DG![`),">")QD@QPDPATD@QRDR+I8#]__]/C80@F7F"6DD!T$R)
MZDC!X@5-B>Q)P>P;3`GB18TD$$V)T$G!X!Y)P>H"30G01(G"3#'`3"'H2#'P
M3(N5B/W__TJ-C!&9>8):2`'!3(G@2,'@!4V)XDG!ZAM,"=!$C10!3(GI2,'A
M'DG![0),">F)R$DQR$TAX$DQT$R+K9#]__]*C;0NF7F"6DD!\$R)UDC!Y@5-
MB=5)P>T;3`GN18TL,$R)YDC!YAY)P>P"3`GF08GP2#'Q3"'12#'!3(NEF/W_
M_TJ-E"*9>8):2`'13(GJ2,'B!4V)[$G![!M,">)$C2013(G22,'B'DG!Z@),
M"=*)T4@QUDPA[DPQQDR+E:#]__]*C800F7F"6D@!QDR)X$C!X`5-B>))P>H;
M3`G01(T4!DR)Z$C!X!Y)P>T"3`GHB<9(,<),(>)(,<I,BZVH_?__3XV$*)EY
M@EI)`=!,B=)(P>(%38G52<'M&TP)ZD6-+!!-B>!)P>`>2<'L`DT)X$2)PDPQ
MP$PAT$@Q\$R+I;#]__]*C8PAF7F"6D@!P4R)Z$C!X`5-B>Q)P>P;3`G@1(TD
M`4R)T4C!X1Y)P>H"3`G1B<A),<A-(>A),=!,BY6X_?__2HVT%IEY@EI)`?!,
MB>9(P>8%38GB2<'J&TP)UD6-%#!,B>Y(P>8>2<'M`DP)[D&)\$@Q\4PAX4@Q
MP4R+K<#]__]*C90JF7F"6D@!T4R)TDC!X@5-B=5)P>T;3`GJ1(TT$4R)XDC!
MXAY)P>P"3`GBB=%(,=9,(=9,,<9,BZ7(_?__2HV$()EY@EI(`<9,B?!(P>`%
M38GT2<'L&TP)X$2-+`9,B=!(P>`>2<'J`DP)T$&)Q$@QPDPA\D@QRDB+M=#]
M__]-C80PF7F"6DD!T$R)ZDC!X@5,B>Y(P>X;2`GRB=))`=!%B<),B?9(P>8>
M2<'N`DP)]D@Q\$PAZ$PQX$B+E=C]__](C8P1F7F"6D@!P4R)T$C!X`5,B=)(
MP>H;2`G0B<!(`<%!B<Y,B>I(P>(>2<'M`DP)ZDB)\$@QT$$QP$B+A>#]__])
MC80$H>O9;DD!P$R)\$C!X`5-B?1)P>P;3`G@B<!)`<!%B<1,B=!(P>`>2<'J
M`DP)T(GV2`.UZ/W__TF)TDDQPD0QT4R-E`ZAZ]EN3(GA2,'A!4R)YDC![AM(
M"?&)R4D!RD6)U4R)\4C!X1Y)P>X"3`GQB=)(`Y7P_?__2(G&2#'.1#'&3(V$
M,J'KV6Y,B>I(P>(%3(GN2,'N&T@)\HG220'018G&3(GF2,'F'DG![`),">:)
MP$@#A?C]__](B<I(,?)$,=),C900H>O9;DR)\$C!X`5,B?)(P>H;2`G0B<!)
M`<)%B=1,B>I(P>(>2<'M`DP)ZHG)2`.-`/[__TB)\$@QT$0QP$R-A`&AZ]EN
M3(G@2,'@!4R)X4C!Z1M("<B)P$D!P$6)Q4R)\$C!X!Y)P>X"3`GPB?9(`[4(
M_O__2(G12#'!1#'13(V4#J'KV6Y,B>E(P>$%3(GN2,'N&T@)\8G)20'*18G6
M3(GA2,'A'DG![`),">&)TD@#E1#^__](B<9(,<Y$,<9,C80RH>O9;DR)\DC!
MX@5,B?9(P>X;2`GRB=))`=!%B<1,B>Y(P>8>2<'M`DP)[HG`2`.%&/[__TB)
MRD@Q\D0QTDR-E!"AZ]EN3(G@2,'@!4R)XDC!ZAM("=")P$D!PD6)U4R)\DC!
MXAY)P>X"3`GRB<E(`XT@_O__2(GP2#'01#'`3(V$`:'KV6Y,B>A(P>`%3(GI
M2,'I&T@)R(G`20'`18G&3(G@2,'@'DG![`),">")]D@#M2C^__](B=%(,<%$
M,=%,C90.H>O9;DR)\4C!X05,B?9(P>X;2`GQB<E)`<I%B=1,B>E(P>$>2<'M
M`DP)Z8G22`.5,/[__TB)QD@QSD0QQDR-A#*AZ]EN3(GB2,'B!4R)YDC![AM(
M"?*)TDD!T$6)Q4R)]DC!YAY)P>X"3`GVB<!(`X4X_O__2(G*2#'R1#'23(V4
M$*'KV6Y,B>A(P>`%3(GJ2,'J&T@)T(G`20'"18G63(GB2,'B'DG![`),">*)
MR4@#C4#^__](B?!(,=!$,<!,C80!H>O9;DR)\$C!X`5,B?%(P>D;2`G(B<!)
M`<!%B<1,B>A(P>`>2<'M`DP)Z(GV2`.U2/[__TB)T4@QP40QT4R-E`ZAZ]EN
M3(GA2,'A!4R)YDC![AM("?&)R4D!RD6)U4R)\4C!X1Y)P>X"3`GQB=)(`Y50
M_O__2(G&2#'.1#'&3(V$,J'KV6Y,B>I(P>(%3(GN2,'N&T@)\HG220'018G&
M3(GF2,'F'DG![`),">:)P$@#A5C^__](B<I(,?)$,=),C:00H>O9;DR)\$C!
MX`5,B?)(P>H;2`G0B<!)`<1%B>),B>I(P>(>2<'M`DP)ZHG)2`.-8/[__TB)
M\$@QT$0QP$R-A`&AZ]EN3(G02,'@!4R)T4C!Z1M("<B)P$D!P$6)Q4R)\$C!
MX!Y)P>X"3`GPB?9(`[5H_O__2(G12#'!1#'A3(VD#J'KV6Y,B>E(P>$%3(GN
M2,'N&T@)\8G)20',18GG3(G12,'A'DG!Z@),"=&)TD@#E7#^__](B<9(,<Y$
M,<9(C;0RH>O9;DR)^DC!X@5-B?A)P>@;3`G"1(T4%DV)Z$G!X!Y)P>T"30GH
M1(G&B<!(`X5X_O__2(G*3#'"1#'B2(V4$*'KV6Y,B=!(P>`%38G42<'L&TP)
MX$2-+`)-B?Q)P>0>2<'O`DT)_$2)XDV)QDT)YDTAUDDAT$T)QKC<O!N/3(N%
M@/[__TD!P(G)3`'!20'.3(GI2,'A!4V)Z$G!Z!M,"<%%C00.3(G12,'A'DG!
MZ@),"=%!B<I)"<Q-(>Q)B<Y)(=9-"?1,B[6(_O__20'&3`'V3`'F38G$2<'D
M!4V)QDG![AM-"?1&C30F3(GN2,'F'DG![0),">Y!B?5)B<Q)"?1-(<1,(>E,
M">%,BZ60_O__20'$3`'B2`'13(GR2,'B!4V)]$G![!M,">)$C2013(G"2,'B
M'DG!Z`),"<)!B=!("=9,(?9(B=%,(>E("<Y(BXV8_O__2`'!3`'12`'Q3(GF
M2,'F!4V)XDG!ZAM,"=9$C3PQ38GR2<'B'DG![@)-"?)$B=9(B=%,"=%,(>%(
M(?)("<I(BXV@_O__2`'!3`'I2`'*3(GY2,'A!4V)_4G![1M,">E$C2P*3(GA
M2,'A'DG![`),">%!B<Q)"<I-(?I(B<I((?))"=)(BY6H_O__2`'"3`'"3`'2
M38GH2<'@!4V)ZDG!ZAM-"=!&C30"38GX2<'@'DG![P)-"?A%B<)(B<I,"<),
M(>I,(=%("=%(BY6P_O__2`'"2`'R2`'13(GR2,'B!4R)]DC![AM("?*--!%,
MB>I(P>(>2<'M`DP)ZD&)U4D)T$TA\$B)T4PAT4D)R$B+C;C^__](`<%,`>%,
M`<%)B?!)P>`%28GT2<'L&TT)X$:-/`%-B?1)P>0>2<'N`DT)]$6)X$B)T4P)
MX4@A\4PAPD@)RDB+C<#^__](`<%,`=%(`<I,B?E(P>$%38GZ2<'J&TP)T42-
M%`I(B?%(P>$>2,'N`D@)\8G.20G,32'\2(G*3"'"20G42(N5R/[__T@!PDP!
MZDP!XDV)U$G!Y`5-B=5)P>T;30GL1HTT(DV)_4G!Y1Y)P>\"30G]18GL2(G*
M3`GJ3"'23"'A2`G12(N5T/[__T@!PDP!PD@!T4R)\DC!X@5-B?!)P>@;3`G"
M1(T$$4R)TDC!XAY)P>H"3`G208G220G532'U2(G13"'A20G-2(N-V/[__T@!
MP4@!\4P!Z4R)QDC!Y@5-B<5)P>T;3`GN1(T\,4R)]DC!YAY)P>X"3`GV08GV
M2(G12`GQ3"'!3"'R2`G*2(N-X/[__T@!P4P!X4@!RDR)^4C!X05-B?Q)P>P;
M3`GA1(TD"DR)P4C!X1Y)P>@"3`G!08G(2`G.3"'^2(G*3"'R2`G62(N5Z/[_
M_T@!PDP!TD@!\DR)YDC!Y@5-B>))P>H;3`G61(TL,DV)^DG!XAY)P>\"30GZ
M1(G62(G*3`G23"'B2"'Q2`G12(N5\/[__T@!PDP!\D@!T4R)ZDC!X@5-B>Y)
MP>X;3`GR1(TT$4R)XDC!XAY)P>P"3`GBB=%)"=)-(>I)B=1)(?1-">),BZ7X
M_O__20'$30'@30'038GR2<'B!4V)]$G![!M-">)'C20038GH2<'@'DG![0)-
M">A%B<))B=5-"<5-(?5,(=),">I,BZT`____20'%3`'N2`'R3(GF2,'F!4V)
MY4G![1M,">Y$C2PR3(GV2,'F'DG![@),"?9!B?=)"?!-(>!(B?),(=))"=!(
MBY4(____2`'"2`'*3`'"3(GI2,'A!4V)Z$G!Z!M,"<%$C00*3(GA2,'A'DG!
M[`),">%!B<Q(B?)("<I,(>I,(>9("=9(BY40____2`'"3`'22`'63(G"2,'B
M!4V)PDG!ZAM,"=*)TD@!UD&)\DR)ZDC!XAY)P>T"3`GJ08G62`G13"'!28G5
M32'E3`GI2`.%&/___TP!^$@!P4R)T$C!X`5-B=5)P>T;3`GHB<!(`<%!B<U,
MB<!(P>`>2<'H`DD)P$PQPC'6N-;!8LI(BY4@____2`'"3`'B2`'R3(GN2,'F
M!4V)[$G![!M,">:)]D@!\D&)U$R)UDC!YAY)P>H"20GR3(G&3#'6,?%(B[4H
M____2`'&20'V20'.3(GA2,'A!4R)YDC![AM("?&)R4D!SD6)]TR)Z4C!X1Y)
MP>T"20G-2(N-,/___T@!P46)P$P!P4R)UDPQ[C'R2`'*3(GY2,'A!4R)_DC!
M[AM("?&)R4@!RD&)T$R)X4C!X1Y)P>P"3`GA2(NU./___T@!QD6)TDP!UDV)
MZDDQRD4Q\DD!\DR)QDC!Y@5-B<1)P>P;3`GFB?9)`?)%B=1,B?Y(P>8>2<'O
M`DD)]TB+M4#___](`<9%B>U,`>Y)B<U-,?U!,=5,`>Y,B>)(P>(%38GE2<'M
M&TD)U46)[4D!]46)[DR)QDC!YAY)P>@"3`G&2(N52/___T@!PHG)2`'*38GX
M23'P13'020'03(GR2,'B!4R)\4C!Z1M("<J)TDD!T$6)PDR)XDC!XAY)P>P"
M20G42(N54/___T@!PD6)_TP!^DB)\4PQX4$QS4D!U4R)TDC!X@5,B=%(P>D;
M2`G*B=))`=5%B>],B?)(P>(>2<'N`DP)\DB+C5C___](`<&)]D@!\4R)YD@Q
MUD$Q\$D!R$R)^4C!X05,B?Y(P>X;2`GQB<E)`<A%B<9,B=%(P>$>2<'J`DD)
MRDB+C6#___](`<%%B>1,`>%)B=1-,=1%,>Q)`<Q,B?%(P>$%3(GV2,'N&T@)
M\8G)20',18GE3(GY2,'A'DG![P),"?E(B[5H____2`'&B=)(`?),B=9(,<Y!
M,?!)`=!,B>I(P>(%3(GN2,'N&T@)\HG220'018G'3(GR2,'B'DG![@))"=9(
MBY5P____2`'"18G23`'228G*33'R13'B20'23(GZ2,'B!4R)_DC![AM("?*)
MTDD!TD6)U$R)[DC!YAY)P>T"3`GN2(N5>/___T@!PHG)2`'*3(GQ2#'Q03'(
M20'03(GB2,'B!4R)X4C!Z1M("<J)TDD!T$6)Q4R)^DC!XAY)P>\"20G72(M5
M@$@!PD6)]DP!\DB)\4PQ^4$QRDD!TDR)ZDC!X@5,B>E(P>D;2`G*B=))`=)%
MB=9,B>)(P>(>2<'L`DP)XDB+38A(`<&)]D@!\4R)_D@QUD0QQD@!SDR)\4C!
MX05-B?!)P>@;3`G!B<E(`<Y!B?!,B>E(P>$>2<'M`DD)S4B+39!(`<%%B?],
M`?E)B=1-,>Q%,=1)`<Q,B<%(P>$%38G"2<'J&TP)T8G)20',18GB3(GQ2,'A
M'DG![@),"?%,BW6820'&B=),`?)-B>Y),<Y$,?9(`=9,B=)(P>(%38G62<'N
M&TP)\HG22`'608GV3(G"2,'B'DG!Z`))"=!(BU6@2`'"18GM3`'J28G-33'%
M13'L20'43(GR2,'B!4V)]4G![1M,">J)TDD!U$2)XDV)U4G!Y1Y)P>H"30GJ
M3(MMJ$D!Q8G)3`'I38G%33'51#'N2`'Q2(G62,'F!4F)U4G![1M,">Z)]D@!
M\8G.38GU2<'E'DG![@)-">Y,BVVP20'%18G`30'H38G533'U13'L30'@28GT
M2<'D!4F)]4G![1M-">Q%`>!)B=1)P>0>2,'J`DP)XD@#1;A)`<%%B=)-`=%,
MB?!(,=`QP4P!R4R)P$C!X`5-B<%)P>D;3`G(`<A(B0=$`T<(3(E'"$B)\$C!
MX!Y(P>X"2`G&00'S3(E?$`':2(E7&$0#=R!,B7<@2(L%OUX@`$B+7<A(*QAU
M$DB!Q)@"``!;05Q!74%>05]=P^A_RO__54B)Y;^`````Z,',__](QP`!(T5G
MNHFKS>](B5`(N?[<NIA(B4@02,=`&'94,A"^\.'2PTB)<"!(QT`H`````$C'
M0#``````QT!X`````%W#54B)Y4%7059!54%44TB#[!A)B?](B?-(8\))B<9(
MBW\HC33'28M7,$@Y_DB#T@!)B7<H2,'H'4@!T$F)1S!)8W]X38UG.(7_=%-!
MO4````!!*?U%.>Y%#T[N26/53`'G2(E5R$B)WNBBR?__08M'>$0!Z$&)1WB#
M^$!(BU7(=`](@\086T%<05U!7D%?7<-%*>Y(`=-,B?_H8>G__T&#_C\/COL`
M``!!@^Y`1(GPP>@&B47(1(UH`4G!Y09)`=U(BP-)B00D2(M#"$F)1"0(2(M#
M$$F)1"002(M#&$F)1"082(M#($F)1"0@2(M#*$F)1"0H2(M#,$F)1"0P2(M#
M.$F)1"0X2(/#0$R)_^CMZ/__3#GK=:F+1<C!X`9!*<9)8\9,B>=,B>Y(@_@(
M<S6H!'4JJ`)U'J@!=1-%B7=X2(/$&%M!7$%=05Y!7UW#I$6)=WCKZF:EJ`%T
MX.OQI:@"=-7K\4'VQ`%U04#VQP*0=5%`]L<$=5](@_@(<K))B<%)@^'X,=),
MBP063(D$%TB#P@A,.<IR[T@!UT@!UJ@$=)+KNDF)W>EU____00^V50!!B%<X
M2(/'`4B#Q@%(@^@!ZZ@/MQ9FB1=(@\<"2(/&`DB#Z`+KFXL6B1=(@\<$2(/&
M!$B#Z`3KCU5(B>5!5T%6055!5%-(@^P(2(G[28GT1(MV*$$/SD2+?C!!#\](
MBT8H2,'H`X/@/TR-;CB-2`%(F$'&1`4`@$AC^4P![X/Y.`^.E@$``+I`````
M*<IT#S'`B<'&!`\`@\`!.=!R\TR)Y^BIY___3(GON3@````QP$'VQ0$/A><!
M``!`]L<"#X7H`0``0/;'!`^%R@$``$&)R$&#X.`QTHG62(D$-TB)1#<(2(E$
M-Q!(B40W&(/"($0YPG+C2`'7]L$0=`1(JTBK]L$(=`)(J_;!!'0!J_;!`G0"
M9JN#X0$/A3,!``!%B7PD<$6)="1T3(GGZ"#G__])BP0D2,'H&(@#28L$)$C!
MZ!"(0P%)BP0D2,'H"(A#`DF+!"2(0P-)BT0D"$C!Z!B(0P1)BT0D"$C!Z!"(
M0P5)BT0D"$C!Z`B(0P9)BT0D"(A#!TF+1"002,'H&(A#"$F+1"002,'H$(A#
M"4F+1"002,'H"(A#"DF+1"00B$,+28M$)!A(P>@8B$,,28M$)!A(P>@0B$,-
M28M$)!A(P>@(B$,.28M$)!B(0P])BT0D($C!Z!B(0Q!)BT0D($C!Z!"(0Q%)
MBT0D($C!Z`B(0Q))BT0D((A#$TR)YTB#Q`A;05Q!74%>05]=Z</%__^Z.```
M`"G*,<"#^B!S+/;"$'0$2*M(J_;""'0"2*OVP@1T`:OVP@)T`F:K@^(!#X3-
M_O__JNG'_O__0/;'`75G0/;'`G5:0/;'!'5.@_H@<KU!B=!!@^#@,?:)\4B)
M!`](B40/"$B)1`\02(E$#QB#QB!$.<9RXT@!]^N2JX/I!.DM_O__JKDW````
MZ0[^__]FJX/I`ND._O__JX/J!.NL9JN#Z@+KGZJ#Z@'KDV8/'T0``.@KQ?__
MZ";%__]52(GE055!5%-(@^PXB7W,2(EUP$B)5;A(BQVG62``2(L#2(E%V#'`
M2(U5N$B-=<!(C7W,Z!W&__](BS6.62``2(GR2(L]I%D@`.A'QO__2(L%8%D@
M`(`X`'4WZ&;%__](B<=(B05$7"``2(7`#X1Z`0``Z)[$__]D2(L$)0````!(
M`P4V62``2(L`QH!>"````&1(BP0E`````$@#!1Q9(`!(BP"`B-H#```#BT7,
M1(U@`XUX!$AC_TC!YP/H5,7__TF)P4B)!=I;(`!(BTW`2(L!28D!2(T%$@,`
M`$F)00A(C05V6R``2(L`28E!$$B-!?P"``!)B4$8BWW,@_\!#X[=````2(/!
M"(/'`[@$````2&/0@\`!2(LQ28DTT4B#P0@Y^'7K2)A)QP3!`````$4QP$R)
MR42)XDB--2C1__](BSUF6R``Z)G%__^%P'112(L]5EL@`.@YQ/__08G$3(UM
MU$R)[DB-/3P!```QP.B1RO__2(7`=#9(BSTM6R``Z-##___H&\7__TB+1=A(
M*P-U8T2)X$B#Q#A;05Q!75W#2(L]!5L@`.BXQ?__ZZ%(BSWG6B``2(7_=`?H
M1^/__^NW3(GN2(T]E````.@TRO__2(G'2(D%PEH@`$B%P'29Z]FX!````.DZ
M____OP$```#H?\+__^BJP___`````````````$B#[`CH.\G__TB#Q`C#```E
M<R\E<P`N`"]P<F]C+V-U<G!R;V,O97AE`$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!005)?5$5-4`!005)?4%)/
M1TY!344`.@!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`#$`
M;'-E96L@9F%I;&5D`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!54T52
M`%-94U1%30`O=&UP+P!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`
M)7,E<R5S)7,`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE+25S)7,`
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ
M4&%C:V5R.CI615)324].`#$N,#8S`"UE`"TM```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.
M('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I
M>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*
M)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M
M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D
M<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]4
M13H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D
M<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F
M+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@
M)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ
M.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U
M;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E
M($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R
M7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!8
M6%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER
M*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE
M;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN
M"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]
M("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D[
M"F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@
M/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%
M3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T
M7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G
M/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@
M9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I
M="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P
M;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P
M*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'
M24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S
M*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP
M0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP
M0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T
M($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P
M.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S
M970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A
M<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR
M96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A
M8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92![
M"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`
M24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U
M;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@
M)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI
M.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^
M>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B
M=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F
M=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@
M34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@
M("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE
M("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]
M"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E
M(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@
M,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`]
M(#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R
M(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E
M<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD
M9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T
M<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM
M>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@
M;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A
M=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*
M)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)
M3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E
M;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@
M(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*
M?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@
M>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE
M9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D
M9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M
M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I
M>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I
M+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T
M.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?
M9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T
M97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP
M(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@
M>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R
M7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D
M1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D
M8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&
M24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?
M;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ
M93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B
M.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP
M9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L
M("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R
M7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M
M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^
M.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F
M("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA
M;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@
M)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH
M*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E
M=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I
M.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D
M<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%2
M7TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,
M14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)0
M05)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF
M(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T
M<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO
M9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN
M:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S
M8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<
M;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*
M``!#04-(10``<&5R;'AS:2YC`````1L#.Q@!```B````Y('__RP"``"DA?__
M5`(``.2%__\T`0``#H;__U@!``!6AO__M`$``*6'__\$`@``A(G__VP"```R
MBO__F`(``(N+___$`@``"XS__^P"``"ZC/__'`,``).-__](`P``M8___W@#
M``#GC___F`,``#20__^X`P``-Y#__\P#```9DO__^`,``$B2__\8!```J)+_
M_U`$``"UEO__?`0```N7__^@!```QY?__[P$``#QF/__Z`0```N9__\(!0``
MR9G__S0%``!*H/__;`4``(:B__^8!0``]*+__^P%``"EN/__'`8``/:X__\\
M!@``W;K__W`&``!TO?__H`$``'F]___P`0``?KW__\`%```4``````````%Z
M4@`!>!`!&PP'")`!```@````'````*B$__\J`````$$.$(8"0PT&0XP#@P1B
M#`<(```@````0````*Z$__](`````$$.$(8"0PT&28T#C`2#!7H,!P@@````
M``````%Z4@`!>!`!&PP'")`!#`80@P6&`HP$C0,````0````*````,R[__\%
M`````````!P```"<````FH3__T\!`````SH!#A"&`D,-!D4,!PC&&```````
M```!>E(``7@0`1L,!PB0`0P&$(8"`!`````@````@;O__P4`````````)```
M`.P```"9A?__(P$```!!#A"&`D,-!D>.`XT$C`6#!@```````"0````4`0``
ML'___\`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````/`$``$B#__\@
M```````````````H````5`$``!"'__^N`````$$.$(8"0PT&38\#C@2-!8P&
M@P<"?PH,!PA!"R@```"``0``DH?__UD!````00X0A@)##090CP..!(T%C`:#
M!WL*#`<(00L`)````*P!``"_B/__@`````!!#A"&`D,-!DJ,`X,$`FP*#`<(
M00L``"P```#4`0``%XG__Z\`````00X0A@)##09*C`.#!`)V"@P'"$$+8`H,
M!PA%"P```"@````$`@``EHG__]D`````00X0A@)##090CP..!(T%C`:#!P*Z
M"@P'"$$++````#`"``!#BO__(@(```!!#A"&`D,-!DV/`XX$C06,!H,'`Q(!
M"@P'"$$+````'````&`"```UC/__,@````!!#A"&`D,-!FD,!P@````<````
M@`(``$>,__]-`````$$.$(8"0PT&18,#?PP'"!````"@`@``=(S__P,`````
M````*````+0"``!CC/__X@$```!!#A"&`D,-!E"/`XX$C06,!H,'`G(*#`<(
M00L<````X`(``!F.__\O`````$$.$(8"0PT&1HP#8`P'"#0``````P``*([_
M_V``````1@X0A@)##09&C`-B"LQ!Q@P'"$4+30K,0<8,!PA%"TD,!PA!QLP`
M*````#@#``!0CO__#00```!!#A"&`D,-!DF-`XP$@P4#S0,*#`<(10L````@
M````9`,``#&2__]6`````$$.$(8"0PT&18,#`D,*#`<(00L8````B`,``&.2
M__^\`````$$.$(8"0PT&````*````*0#```#D___*@$```!!#A"&`D,-!E"/
M`XX$C06,!H,'`M8*#`<(00L<````T`,```&4__\:`````$$.$(8"0PT&50P'
M"````"@```#P`P``^Y/__[X`````00X0A@)##09+C@.-!(P%@P8"4PH,!PA%
M"P``-````!P$``"-E/__@08```!!#A"&`D,-!E"/`XX$C06,!H,'`TT""@P'
M"$$+`_H""@P'"$4+```H````5`0``-::__\\`@```$$.$(8"0PT&2XX#C02,
M!8,&`ZH!"@P'"$$+`"0```"`!```YIS__V4`````00X0A@)##09&C`-A"@P'
M"$$+=`P'"``H````J`0``+:W___\`0```$$.$(8"0PT&28T#C`2#!0.4`0H,
M!PA!"P```"P```#4!````)W__[$5````00X0A@)##090CP..!(T%C`:#!P.7
M%0H,!PA!"P```!P````$!0``@;+__U$`````00X0A@)##08"3`P'"```,```
M`"0%``"RLO__YP$```!!#A"&`D,-!DV/`XX$C06,!H,'`GT*#`<(00L"O0H,
M!PA!"RP```!8!0``9;3__Y$"````00X0A@)##09-CP..!(T%C`:#!P/.`0H,
M!PA%"P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````+L"`````````0``````
M``#%`@````````$`````````V@(````````!`````````/D"````````#P``
M``````!F!`````````P`````````4!H````````-``````````!8````````
M!`````````!(`@````````4`````````J`X````````&`````````&`%````
M````"@````````"M!`````````L`````````&``````````5````````````
M`````````P``````````L"````````(`````````B`4````````4````````
M``<`````````%P````````#`%`````````<`````````6!,````````(````
M`````&@!````````"0`````````8`````````/O__V\`````````"`````#Y
M__]O``````0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````X*T@````````````````````````
M``````````````#@K2````````````````````````````!V&@```````(8:
M````````EAH```````"F&@```````+8:````````QAH```````#6&@``````
M`.8:````````]AH````````&&P```````!8;````````)AL````````V&P``
M`````$8;````````5AL```````!F&P```````'8;````````AAL```````"6
M&P```````*8;````````MAL```````#&&P```````-8;````````YAL`````
M``#V&P````````8<````````%AP````````F'````````#8<````````1AP`
M``````!6'````````&8<````````=AP```````"&'````````)8<````````
MIAP```````"V'````````,8<````````UAP```````#F'````````/8<````
M````!AT````````6'0```````"8=````````-AT```````!&'0```````%8=
M````````9AT```````!V'0```````(8=````````EAT```````"F'0``````
M`+8=````````QAT```````#6'0```````.8=````````]AT````````&'@``
M`````!8>````````B+(@``````#XL2``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````I005(N<&T*``````````#X6@```````$=#0SH@*$YE=$)3
M1"!N8C,@,C`R,S$P,#@I(#$P+C4N,`!'0T,Z("AN8C,@,C`R,S$P,#@I(#$P
M+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q+C0@,C`Q."\Q,2\R-B`Q-SHS-SHT
M-B!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G0P+6-O;6UO;BYC+'8@,2XR-R`R
M,#(R+S`V+S(Q(#`V.C4R.C$W('-K<FQL($5X<"`D`"1.971"4T0Z(&-R=&DN
M4RQV(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,U(&IO97)G($5X<"`D`"1.971"
M4T0Z(&-R=&)E9VEN+E,L=B`Q+C(@,C`Q,"\Q,2\S,"`Q.#HS-SHU.2!J;V5R
M9R!%>'`@)``D3F5T0E-$.B!C<G1E;F0N4RQV(#$N,2`R,#$P+S`X+S`W(#$X
M.C`Q.C,T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=&XN4RQV(#$N,2`R,#$P
M+S`X+S`W(#$X.C`Q.C,U(&IO97)G($5X<"`D``#QSP(`````````````````
M"`````@````(````"````!L````!```````````J*BH@3F\@3&%B96P@4')O
M=FED960@*BHJ``#QSP(`````````````````"`````@````(````"````!L`
M```!```````````J*BH@3F\@3&%B96P@4')O=FED960@*BHJ```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YN971B<V0N:61E;G0`+FYO=&4N;F5T8G-D+G!A
M>``N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T
M+G!L=``N9&%T80`N8G-S`"YC;VUM96YT`"Y354Y77V-T9@``````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(```````````(``````````@```````!<`
M```````````````````!````````````````````$P````<````"````````
M`!@"````````&`(````````8````````````````````!```````````````
M`````"8````'`````@`````````P`@```````#`"````````%```````````
M``````````0````````````````````W````!0````(`````````2`(`````
M``!(`@```````!@#````````!0`````````(``````````0`````````/0``
M``L````"`````````&`%````````8`4```````!("0````````8````!````
M"``````````8`````````$4````#`````@````````"H#@```````*@.````
M````K00```````````````````$```````````````````!-````!`````(`
M````````6!,```````!8$P```````&@!````````!0`````````(````````
M`!@`````````5P````0```!"`````````,`4````````P!0```````"(!0``
M``````4````6````"``````````8`````````&$````!````!@````````!0
M&@```````%`:````````#@```````````````````!``````````````````
M``!<`````0````8`````````8!H```````!@&@```````,`#````````````
M```````0`````````!``````````9P````$````&`````````"`>````````
M(!X````````@````````````````````"``````````(`````````'`````!
M````!@````````!`'@```````$`>````````MCD``````````````````!``
M``````````````````!V`````0````8``````````%@`````````6```````
M``X````````````````````0````````````````````?`````$````"````
M`````!!8````````$%@```````!J0```````````````````"```````````
M`````````(0````!`````@````````!\F````````'R8````````'`$`````
M``````````````0```````````````````"2`````0````(`````````F)D`
M``````"8F0```````(P%```````````````````(````````````````````
MG`````$````#`````````+BM(```````N*T````````0````````````````
M````"````````````````````*,````!`````P````````#(K2```````,BM
M````````$`````````````````````@```````````````````"J`````0``
M``,`````````V*T@``````#8K0````````@````````````````````(````
M````````````````KP````8````#`````````."M(```````X*T```````#`
M`0````````8`````````"``````````0`````````&L````!`````P``````
M``"@KR```````*"O````````8`````````````````````@`````````"```
M``````"X`````0````,``````````+`@````````L````````/`!````````
M```````````(``````````@`````````P0````$````#`````````/"Q(```
M````\+$```````!P````````````````````"````````````````````,<`
M```(`````P````````"`LB```````&"R````````2```````````````````
M`$````````````````````#,`````0```#````````````````````!@L@``
M`````#T````````````````````!``````````$`````````'P````$````P
M````````````````````G;(```````!2`0```````````````````0``````
M```!`````````-4````!`````````````````````````/"S````````CP``
M``````````````````0````````````````````!`````P``````````````
M``````````!_M````````-\````````````````````!````````````````
#````
